# Bryan Schumaker (4 / 30 / 2011)

import libsaria

def null_cb(*args):
	pass

on_play = null_cb
def play():
	on_play()

on_pause = null_cb
def pause():
	on_pause()

on_load = null_cb
def load_file(file):
	on_load(file)

on_like = null_cb
def like_song(like):
	on_like(like)

on_set_volume = null_cb
def set_volume(prcnt):
	on_set_volume(prcnt)

on_get_art = null_cb
def get_art(file, id):
	on_get_art(file, id)

on_load_playlist = null_cb
def load_playlist():
	on_load_playlist()

on_new_source = null_cb
def new_source():
	on_new_source()
